/****************************************************************
 * ItalkServer.cc : Italk-Server status class
 *
 * (c) 1997 Yutaka Oiwa.
 *
 * $Id: ItalkServer.cc,v 1.2 1997/12/28 13:28:04 yutaka Exp $
 ****************************************************************/

#include <stdlib.h>
#include "Defines.h"
#include "ItalkServer.h"

ItalkServer::ItalkServer(const char *name_, int port_,
			 ItalkServer_callback_t callback_, void *app_data_) {
  name = NewString(name_);
  port = port_;
  callback = callback_;
  app_data = app_data_;
  message = 0;

  add_to = 1;

  for (int i=0; i < 2; i++) {
    n_monkeys[i] = 0;
    for (int j=0; j < MAX_MONKEY; j++) {
      monkeys[i][j] = NULL;
    }
  }
}

const Monkey *const * ItalkServer::GetMonkeys(void) const {
  return monkeys[!add_to];
}

void ItalkServer::AddMonkey(Monkey *p) {
  if (n_monkeys[add_to] <= MAX_MONKEY) {
    monkeys[add_to][n_monkeys[add_to]++] = p;
  }
}

void ItalkServer::AddMessage(const char *p) {
  dprintf("MESSAGE: %s\n", p);
  if (message)
    delete[] message;
  message = NewString(p);
}

void ItalkServer::DeleteMessage() {
  dprintf("MESSAGE: removed\n");
  if (message)
    delete[] message;
  message = NULL;
}

void ItalkServer::DataFinished() {
  int f = (n_monkeys[add_to] > n_monkeys[!add_to]);
  add_to = !add_to;
  
  n_monkeys[add_to] = 0;
  for(int i=0; i < MAX_MONKEY; i++)
    if (monkeys[add_to][i]) {
      delete monkeys[add_to][i];
      monkeys[add_to][i] = NULL;
    }

  if (callback) 
    callback(f, app_data);
}
